@@ -13,7 +13,8 @@
 #' @param verbose A \code{logical} value indicating whether to be verbose or not. Is ignored if \code{method = "discrete"}.
 #' @param t0 If \code{time} is a number of samples, whether to start the sampling from the \code{tree$root.time} (\code{TRUE}), or from the first sample containing at least three elements (\code{FALSE} - default) or from a fixed time point (if \code{t0} is a single \code{numeric} value).
 #' @param bind.data If \code{data} contains multiple matrices and \code{tree} contains the same number of trees, whether to bind the pairs of matrices and the trees (\code{TRUE}) or not (\code{FALSE} - default).
-#' 
+#' @param dist.data A \code{logical} value indicating whether to treat the data as distance data (\code{TRUE}) or not (\code{FALSE} - default).
+
 #' 
 #' 
 #'  
@@ -95,7 +96,7 @@
 # t0 = 5
 # bind.data = TRUE
 
-chrono.subsets <- function(data, tree = NULL, method, time, model, inc.nodes = FALSE, FADLAD = NULL, verbose = FALSE, t0 = FALSE, bind.data = FALSE) {
+chrono.subsets <- function(data, tree = NULL, method, time, model, inc.nodes = FALSE, FADLAD = NULL, verbose = FALSE, t0 = FALSE, bind.data = FALSE, dist.data = FALSE) {
     match_call <- match.call()
 
     ## ----------------------
@@ -150,7 +151,7 @@ chrono.subsets <- function(data, tree = NULL, method, time, model, inc.nodes = F
             if(verbose) message("Creating ", length(time), " time samples through ", length(matrices), " trees and matrices:", appendLF = FALSE)
         }
 
-        output <- dispRity.multi.apply(matrices, fun = chrono.subsets.call, tree = tree, method = method, time = time, model = model, inc.nodes = inc.nodes, FADLAD = FADLAD, verbose = verbose, t0 = t0, bind.data = bind.data)
+        output <- dispRity.multi.apply(matrices, fun = chrono.subsets.call, tree = tree, method = method, time = time, model = model, inc.nodes = inc.nodes, FADLAD = FADLAD, verbose = verbose, t0 = t0, bind.data = bind.data, dist.data = dist.data)
 
         if(verbose) message("Done.\n", appendLF = FALSE)
         return(output)
@@ -215,7 +216,7 @@ chrono.subsets <- function(data, tree = NULL, method, time, model, inc.nodes = F
 
                     tree <- lapply(tree, stretch.tree, root = max(root_time))
                     class(tree) <- "multiPhylo"
-                    warning(paste0("Differing root times in ", as.expression(match_call$tree), ". The $root.time for all tree has been set to the maximum (oldest) root time: ", max(root_time), " by stretching the root edge."))
+                    warning(paste0("Differing root times in ", as.expression(match_call$tree), ". The $root.time for all tree has been set to the maximum (oldest) root time: ", round(max(root_time), 3), " by stretching the root edge."))
                 }
             }
         } else {
@@ -445,7 +446,7 @@ chrono.subsets <- function(data, tree = NULL, method, time, model, inc.nodes = F
         check.class(bind.data, "logical")
     } else {
         if(bind.data) {
-            stop(paste0("Impossible to bind the data to the trees since the number of matrices (", length(data), ") is not equal to the number of trees (", length(tree), ")."))
+            stop(paste0("Impossible to bind the data to the trees since the number of matrices (", length(data), ") is not equal to the number of trees (", length(tree), ")."), call. = FALSE)
         }
     }
 
