@@ -1,14 +1,19 @@
 ## Cleaning a tree so that the species match with the ones in a table
-clean.tree.table <- function(tree, data) {
+clean.tree.table <- function(tree, data, inc.nodes) {
 
     ## Intersecting names between both data sets
-    matching_names <- intersect(tree$tip.label, rownames(data))
+    if(inc.nodes) {
+        labels <- c(tree$tip.label, tree$node.label)
+    } else {
+        labels <- tree$tip.label
+    }
+    matching_names <- intersect(labels, rownames(data))
 
     ## Which data is present
     data_match <- rownames(data) %in% matching_names
 
     ## Which tips are present
-    tips_match <- tree$tip.label %in% matching_names
+    tips_match <- labels %in% matching_names
 
     ## Matching the data    
     if(all(data_match)) {
@@ -23,8 +28,12 @@ clean.tree.table <- function(tree, data) {
     if(all(tips_match)) {
         dropped_tips <- NA
     } else {
-        dropped_tips <- tree$tip.label[!tips_match]
-        tree <- drop.tip(tree, tip = dropped_tips)
+        dropped_tips <- labels[!tips_match]
+        if(any(dropped_tips %in% tree$node.label)) {
+            return(dropped_tips[dropped_tips %in% tree$node.label])
+        } else {
+            tree <- drop.tip(tree, tip = dropped_tips)
+        }
     }
 
     return(list("tree" = tree, "data" = data, "dropped_tips" = dropped_tips, "dropped_rows" = dropped_rows))
