@@ -22,7 +22,7 @@ make.null.model <- function(data, replicates, null.distrib, null.args, null.cor,
                                     arguments = null.args,
                                     cor.matrix = null.cor,
                                     scree = null.scree),
-                            metric = metric, dimensions = data$call$dimensions),
+                            metric = metric, dimensions = 1:length(data$call$dimensions)),
                     cent.tend = mean, quantiles = 1)$obs)
         } else {
                 null_models_result <- replicate(replicates, summary(dispRity(
@@ -32,8 +32,9 @@ make.null.model <- function(data, replicates, null.distrib, null.args, null.cor,
                                     arguments = null.args,
                                     cor.matrix = null.cor,
                                     scree = null.scree),
-                            metric = metric, dimensions = data$call$dimensions, args),
-                    cent.tend = mean, quantiles = 1)$obs)        }
+                            metric = metric, dimensions = 1:length(data$call$dimensions), args),
+                    cent.tend = mean, quantiles = 1)$obs)
+                }
     } else {
         if(is.null(args)) {
             null_models_result <- replicate(replicates, summary(dispRity(
@@ -45,7 +46,7 @@ make.null.model <- function(data, replicates, null.distrib, null.args, null.cor,
                                     cor.matrix = null.cor,
                                     scree = null.scree)
                         ),
-                    metric = metric, dimensions = data$call$dimensions),
+                    metric = metric, dimensions = 1:length(data$call$dimensions)),
             cent.tend = mean, quantiles = 1)$obs)
         } else {
             null_models_result <- replicate(replicates, summary(dispRity(
@@ -57,7 +58,7 @@ make.null.model <- function(data, replicates, null.distrib, null.args, null.cor,
                                     cor.matrix = null.cor,
                                     scree = null.scree)
                         ),
-                    metric = metric, dimensions = data$call$dimensions, args),
+                    metric = metric, dimensions = 1:length(data$call$dimensions), args),
             cent.tend = mean, quantiles = 1)$obs)
         }
     }
